<h1>BlueTE 2.0</h1>
A CLI to generate a Discord Bot project in Python!

<h2>Getting Started</h2>
1. Clone the BlueTE Repository 
<br>
2. Once cloned, run start.sh

**For Windows:**
```bash
bash start.sh
```

**For Mac/Linux:**
```sh
sh start.sh
```

Alternatively, you can use the `launcher.py` file to launch BlueTE

Once you're bot files are generated in a folder, go into the bot.py file and fill in the spaces where it says "ur prefered default prefix here"

Thats it! You can now run your bot and add to it. You can use BlueTE 2.0 as many times as you would like.

<h2>Errors</h2>
If you come across an error using BlueTE 2.0, please make a new issue in the Issues section of this GitHub repository.

Also, feel free to make any pull requests if you feel something can be fixed, updated, etc!

Thanks!
